#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from pyramid.httpexceptions import HTTPSeeOther

from pyams_content.shared.site import ISiteElementNavigation
from pyams_content.shared.site.interfaces import FOLDER_REDIRECT_DISPLAY_MODE, ISiteFolder
from pyams_default_theme.interfaces import IContentSummaryInfo
from pyams_i18n.interfaces import II18n
from pyams_pagelet.pagelet import pagelet_config
from pyams_portal.views import PortalContextIndexPage, PortalContextPreviewPage
from pyams_skin.layer import IPyAMSUserLayer
from pyams_utils.adapter import ContextRequestAdapter, adapter_config
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION
from pyams_utils.url import relative_url
from pyams_workflow.interfaces import IWorkflowPublicationInfo

from pyams_default_theme import _


@adapter_config(context=(ISiteFolder, IPyAMSUserLayer), provides=ISiteElementNavigation)
class SiteFolderNavigationAdapter(ContextRequestAdapter):
    """Site folder navigation adapter"""

    @property
    def visible(self):
        if not self.context.visible_in_list:
            return False
        return IWorkflowPublicationInfo(self.context).is_visible(self.request)


@adapter_config(context=(ISiteFolder, IPyAMSUserLayer), provides=IContentSummaryInfo)
class SiteFolderSummaryAdapter(ContextRequestAdapter):
    """Site folder summary adapter"""

    @property
    def title(self):
        i18n = II18n(self.context)
        return i18n.query_attribute('navigation_title', request=self.request) or \
               i18n.query_attribute('title', request=self.request)

    @property
    def header(self):
        try:
            return II18n(self.context).query_attribute('header', request=self.request)
        except AttributeError:
            return None

    button_title = _("Consult folder")


@pagelet_config(name='', context=ISiteFolder, layer=IPyAMSUserLayer)
class SiteFolderIndexPage(PortalContextIndexPage):
    """Site folder index page"""

    def __call__(self, **kwargs):
        if self.context.navigation_mode == FOLDER_REDIRECT_DISPLAY_MODE:
            target = next(self.context.get_visible_items(self.request), None)
            if target is not None:
                return HTTPSeeOther(relative_url(target, request=self.request))
        return super(SiteFolderIndexPage, self).__call__(**kwargs)


@pagelet_config(name='preview.html', context=ISiteFolder, layer=IPyAMSUserLayer, permission=VIEW_SYSTEM_PERMISSION)
class SiteFolderPreviewPage(PortalContextPreviewPage):
    """Site folder preview page"""

    def __call__(self, **kwargs):
        if self.context.navigation_mode == FOLDER_REDIRECT_DISPLAY_MODE:
            target = next(self.context.get_visible_items(self.request), None)
            if target is not None:
                return HTTPSeeOther(relative_url(target, request=self.request, view_name='preview.html'))
        return super(SiteFolderPreviewPage, self).__call__(**kwargs)
